fn get_row_value(app: &App, row: SettingRow) -> (String, Color)Expand description
Get the display value and color for a settings row.
fn get_row_value(app: &App, row: SettingRow) -> (String, Color)Get the display value and color for a settings row.